# coding: utf-8

"""
ProvidersApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class ProvidersApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def providers_get(self, search_term, zip_code, **kwargs):
        """
        Find providers by term and zip code
        All `Provider` searches require a `zip_code`, which we use for weighting
the search results to favor `Provider`s that are near the user.  For example,
we would want "Dr. John Smith" who is 5 miles away to appear before
"Dr. John Smith" who is 100 miles away.

The weighting also allows for non-exact matches.  In our prior example, we
would want "Dr. Jon Smith" who is 2 miles away to appear before the exact
match "Dr. John Smith" who is 100 miles away because it is more likely that
the user just entered an incorrect name.

The free text search also supports Specialty name search and "body part"
Specialty name search.  So, searching "John Smith nose" would return
"Dr. John Smith", the ENT Specialist before "Dr. John Smith" the Internist.



        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.providers_get(search_term, zip_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str search_term: String to search by (required)
        :param str zip_code: Zip Code to search near (required)
        :param str accepts_insurance: Limit results to Providers who accept at least one insurance plan.  Note that the inverse of this filter is not supported and any value will evaluate to true
        :param list[str] hios_ids: HIOS id of one or more plans
        :param str page: Page number
        :param str per_page: Number of records to return per page
        :param str radius: Radius (in miles) to use to limit results
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['search_term', 'zip_code', 'accepts_insurance', 'hios_ids', 'page', 'per_page', 'radius']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method providers_get" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'search_term' is set
        if ('search_term' not in params) or (params['search_term'] is None):
            raise ValueError("Missing the required parameter `search_term` when calling `providers_get`")
        # verify the required parameter 'zip_code' is set
        if ('zip_code' not in params) or (params['zip_code'] is None):
            raise ValueError("Missing the required parameter `zip_code` when calling `providers_get`")

        resource_path = '/providers'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'accepts_insurance' in params:
            query_params['accepts_insurance'] = params['accepts_insurance']
        if 'hios_ids' in params:
            query_params['hios_ids'] = params['hios_ids']
        if 'page' in params:
            query_params['page'] = params['page']
        if 'per_page' in params:
            query_params['per_page'] = params['per_page']
        if 'radius' in params:
            query_params['radius'] = params['radius']
        if 'search_term' in params:
            query_params['search_term'] = params['search_term']
        if 'zip_code' in params:
            query_params['zip_code'] = params['zip_code']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept([])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='InlineResponse200',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def providers_npi_get(self, npi, **kwargs):
        """
        Find a specific Provider
        To retrieve a specific provider, just perform a GET using his NPI number



        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.providers_npi_get(npi, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str npi: NPI number (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['npi']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method providers_npi_get" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'npi' is set
        if ('npi' not in params) or (params['npi'] is None):
            raise ValueError("Missing the required parameter `npi` when calling `providers_npi_get`")

        resource_path = '/providers/{npi}'.replace('{format}', 'json')
        path_params = {}
        if 'npi' in params:
            path_params['npi'] = params['npi']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept([])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='InlineResponse2001',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
